==> tuia-treasure-center-api-1.8.4.2-bypass-20190115.084732-1-sources.jar: cn/tuia/tuia/treasure/center/api/dto/ArticleAbTestReq.java <==
package cn.tuia.tuia.treasure.center.api.dto;


import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Create by yuanwei
 * at 2018/12/11 0011 下午 15:20
 */
@ApiModel("文章abTest入参")
public class ArticleAbTestReq implements Serializable{

    @ApiModelProperty(value = "文章标题")
    private String title;
    @ApiModelProperty(value = "当时日期")
    private String curDate;
    @ApiModelProperty(value = "标签")
    private String tag;
    @ApiModelProperty(value = "作者")
    private String auther;
    @ApiModelProperty(value = "发布时间")
    private Date pushTime;


    private String startTime;
    private String endTime;

    private List<Long> accountIds;

    private Long id;

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }


    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public String getAuther() {
        return auther;
    }

    public void setAuther(String auther) {
        this.auther = auther;
    }

    public Date getPushTime() {
        return pushTime;
    }

    public void setPushTime(Date pushTime) {
        this.pushTime = pushTime;
    }

    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getCurDate() {
        return curDate;
    }

    public List<Long> getAccountIds() {
        return accountIds;
    }

    public void setAccountIds(List<Long> accountIds) {
        this.accountIds = accountIds;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }
}

==> tuia-treasure-center-api-1.8.4.3-bypass-20190117.060601-7-sources.jar: cn/tuia/tuia/treasure/center/api/dto/ArticleAbTestReq.java <==
package cn.tuia.tuia.treasure.center.api.dto;


import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * Create by yuanwei
 * at 2018/12/11 0011 下午 15:20
 */
@ApiModel("文章abTest入参")
public class ArticleAbTestReq implements Serializable{

    @ApiModelProperty(value = "文章标题")
    private String title;
    @ApiModelProperty(value = "当时日期")
    private String curDate;
    @ApiModelProperty(value = "标签")
    private String tag;
    @ApiModelProperty(value = "作者")
    private String auther;
    @ApiModelProperty(value = "发布时间")
    private Date pushTime;
    @ApiModelProperty(value = "是否是新人工推荐 0:否 1:是")
    private Integer isNewRecommend;
    @ApiModelProperty(value = "推荐标签")
    private Integer recommendTag;


    private String startTime;
    private String endTime;

    private List<Long> accountIds;

    private Long id;

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }


    public String getTag() {
        return tag;
    }

    public void setTag(String tag) {
        this.tag = tag;
    }

    public String getAuther() {
        return auther;
    }

    public void setAuther(String auther) {
        this.auther = auther;
    }

    public Date getPushTime() {
        return pushTime;
    }

    public void setPushTime(Date pushTime) {
        this.pushTime = pushTime;
    }

    public void setCurDate(String curDate) {
        this.curDate = curDate;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getCurDate() {
        return curDate;
    }

    public List<Long> getAccountIds() {
        return accountIds;
    }

    public void setAccountIds(List<Long> accountIds) {
        this.accountIds = accountIds;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getIsNewRecommend() {
        return isNewRecommend;
    }

    public void setIsNewRecommend(Integer isNewRecommend) {
        this.isNewRecommend = isNewRecommend;
    }

    public Integer getRecommendTag() {
        return recommendTag;
    }

    public void setRecommendTag(Integer recommendTag) {
        this.recommendTag = recommendTag;
    }
}
